@@ -69,7 +69,9 @@ ZIG_KEYWORDS = frozenset(
 )
 ZIG_TYPE_TOKENS = frozenset({"builtin_type", "f64"})
 ZIG_NUMERIC_TOKENS = frozenset({"integer", "float"})
-ZIG_STRING_TOKENS = frozenset({"string_content", "multiline_string", '"'})
+ZIG_STRING_TOKENS = frozenset(
+    {"string_content", "multiline_string", '"', "'", "character_content"}
+)
 
 _KIND_MAPPINGS = {
     "comment": Style(Color.GRAY),
@@ -118,7 +120,7 @@ def _adjust_string_idents(body: Body, token: Token) -> None:
         del body[-3]
 
 
-def _process_zig_tokens(source: str, tokens: Iterator[Token]) -> str:
+def _process_zig_tokens(source: bytes, tokens: Iterator[Token]) -> str:
     body: Body = []
     pointer = 0
     token = next(tokens)
@@ -128,7 +130,7 @@ def _process_zig_tokens(source: str, tokens: Iterator[Token]) -> str:
         filler = source[pointer : token.byte_range.start]
         if not filler.isspace():
             _adjust_reset(body)
-        body.append(filler)
+        body.append(filler.decode())
         pointer = token.byte_range.start
 
     while pointer < len(source):
@@ -164,16 +166,24 @@ def _process_zig_tokens(source: str, tokens: Iterator[Token]) -> str:
     return "".join(map(str, body))
 
 
-def highlight_zig_code(source: str) -> str:
-    """Return an ANSI syntax-highlighted version of the given Zig source code."""
+def highlight_zig_code(source: str | bytes) -> str:
+    """
+    Return an ANSI syntax-highlighted version of the given Zig source code.
+    Assumes UTF-8 if source is `bytes`.
+    """
+    if isinstance(source, str):
+        source = source.encode()
     return _process_zig_tokens(source, tokenize_zig(source))
 
 
-def process_markdown(source: str, *, only_code: bool = False) -> str:
+def process_markdown(source: str | bytes, *, only_code: bool = False) -> str:
     """
     Return a Markdown source with Zig code blocks syntax-highlighted.
     If `only_code` is True, only processed Zig code blocks will be returned.
+    Assumes UTF-8 if source is `bytes`.
     """
+    if isinstance(source, bytes):
+        source = source.decode()
     zig_codeblocks = (
         block.body for block in extract_codeblocks(source) if block.lang == "zig"
     )
